@@ -10,8 +10,10 @@ extern bool use_debug;
 extern bool flush_cache;
 extern bool patterns_are_regex;
 extern bool use_extended_regex;
+extern bool check_existence;
 extern int64_t limit_matches;
 extern int64_t limit_left;  // Not strictly an option.
 extern bool stdout_is_tty;  // Same.
+extern bool literal_printing;
 
 #endif  // !defined(_OPTIONS_H)
